@@ -456,8 +456,8 @@ gboolean purple_markup_find_tag(const char *needle, const char *haystack,
 /**
  * Extracts a field of data from HTML.
  *
- * This is a scary function. See protocols/msn/msn.c and
- * protocols/yahoo/yahoo_profile.c for example usage.
+ * This is a scary function. It used to be used for MSN and Yahoo prpls,
+ * but since those prpls have been removed, this is now deprecated.
  *
  * @param str            The string to parse.
  * @param len            The size of str.
@@ -1330,6 +1330,17 @@ GList *purple_uri_list_extract_uris(const gchar *uri_list);
  */
 GList *purple_uri_list_extract_filenames(const gchar *uri_list);
 
+/**
+ * This function escapes any characters that might be interpreted by the shell
+ * when executing a program to open a URI on some systems.
+ *
+ * @param unescaped The unescaped URI.
+ *
+ * @return A newly allocated string with any shell metacharacters replaced with
+ * their escaped equivalents.
+ */
+char *purple_uri_escape_for_open(const char *unescaped);
+
 /*@}*/
 
 /**************************************************************************
